@@ -112,7 +112,16 @@ def get_latest_folder(folder):
 def get_database_config_file():
     """Get the absolute path to the database configuration file."""
     cfg = get_project_configuration()
-    return cfg['dbconfig']
+    if 'dbconfig' in cfg:
+        if os.path.isfile(cfg['dbconfig']):
+            return cfg['dbconfig']
+        else:
+            logging.info("File '%s' was not found. Adjust 'dbconfig' in your "
+                         "~/.hwrtrc file.")
+    else:
+        logging.info("No database connection file found. "
+                     "Specify 'dbconfig' in your ~/.hwrtrc file.")
+    return None
 
 
 def get_database_configuration():
